@@ -128,6 +128,8 @@ func NewCmdRun(f *cmdutil.Factory, runF func(*RunOptions) error) *cobra.Command
 	cmd.Flags().StringArrayVarP(&opts.RawFields, "raw-field", "f", nil, "Add a string parameter in `key=value` format")
 	cmd.Flags().BoolVar(&opts.JSON, "json", false, "Read workflow inputs as JSON via STDIN")
 
+	_ = cmdutil.RegisterBranchCompletionFlags(f.GitClient, cmd, "ref")
+
 	return cmd
 }
 
@@ -230,6 +232,7 @@ func collectInputs(yamlContent []byte) (map[string]string, error) {
 	inputAnswer := InputAnswer{
 		providedInputs: providedInputs,
 	}
+	//nolint:staticcheck // SA1019: prompt.SurveyAsk is deprecated: use Prompter
 	err = prompt.SurveyAsk(qs, &inputAnswer)
 	if err != nil {
 		return nil, err
@@ -247,7 +250,7 @@ func runRun(opts *RunOptions) error {
 
 	repo, err := opts.BaseRepo()
 	if err != nil {
-		return fmt.Errorf("could not determine base repo: %w", err)
+		return err
 	}
 
 	ref := opts.Ref
