@@ -305,6 +305,13 @@ func (s *IOStreams) StopProgressIndicator() {
 	s.progressIndicator = nil
 }
 
+func (s *IOStreams) RunWithProgress(label string, run func() error) error {
+	s.StartProgressIndicatorWithLabel(label)
+	defer s.StopProgressIndicator()
+
+	return run()
+}
+
 func (s *IOStreams) StartAlternateScreenBuffer() {
 	if s.alternateScreenBufferEnabled {
 		s.alternateScreenBufferMu.Lock()
@@ -341,7 +348,7 @@ func (s *IOStreams) SetAlternateScreenBufferEnabled(enabled bool) {
 }
 
 func (s *IOStreams) RefreshScreen() {
-	if s.stdoutIsTTY {
+	if s.IsStdoutTTY() {
 		// Move cursor to 0,0
 		fmt.Fprint(s.Out, "\x1b[0;0H")
 		// Clear from cursor to bottom of screen
@@ -407,8 +414,9 @@ func System() *IOStreams {
 	}
 
 	stdoutIsTTY := io.IsStdoutTTY()
+	stderrIsTTY := io.IsStderrTTY()
 
-	if stdoutIsTTY && io.IsStderrTTY() {
+	if stdoutIsTTY && stderrIsTTY {
 		io.progressIndicatorEnabled = true
 	}
 
